(***********************************************************************)
(*                                                                     *)
(*                           Htmlc                                     *)
(*                                                                     *)
(*                    Pierre Weis, INRIA Rocquencourt                  *)
(*                                                                     *)
(*  Copyright 1997-2007,                                               *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  Distributed only by permission.                                    *)
(*                                                                     *)
(***********************************************************************)

(* $Id: debug.ml,v 1.7 2009/02/19 20:26:51 weis Exp $ *)

(** {3 Some simple tools to debug the compiler} *)

open Setting;;

let htmlc_setting = Setting.default;;

let get_debug, set_debug =
  (fun () -> htmlc_setting.Setting.debug),
  (fun () -> htmlc_setting.debug <- true)
;;

let get_print_env, set_print_env =
  (fun () -> htmlc_setting.print_env),
  (fun () -> htmlc_setting.print_env <- true)
;;

let get_print_setting, set_print_setting =
  (fun () -> htmlc_setting.print_setting),
  (fun () -> htmlc_setting.print_setting <- true)
;;

(** A special [Env.failwith] function to be able to trace failure strings. *)
let failwith failure_string =
  if get_debug () then prerr_endline failure_string;
  raise (Failure failure_string)
;;

let printf fmt =
  if get_debug () then Printf.fprintf stderr fmt else Printf.ifprintf stderr fmt
;;
