(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(** {3 The main procedure of the [Htmlc] compiler} *)

exception Error of string * int * exn;;

val string_of_exc : exn -> string;;

val treat_buffer : Path.file_name -> Buffer.t ->
  Scanf.Scanning.scanbuf -> unit
;;

val treat_domains : Io_domain.t -> Io_domain.t -> unit
;;

(** {6 Setting the result file permissions} *)

val set_writable_target : bool -> unit
(** By default the Htmlc compiled files are read only, to prevent the user
    from editing a file that can be overwritten at any time.
    Nonetheless, evaluating [set_writable_target true] allows to obtain a
    writable target file. *)
;;

val set_target_perms : int -> unit
(** Set the given permissions in order to set the permissions of the target
  file afterwards. *)
;;

(** {6 Server Side Include directives} *)

(** We define bells and whistles for Server Side Include directives (SSI
    directives for short). *)

val set_honor_ssi_directive : bool -> unit
(** Do we evaluate SSI directives or not ? *)
;;

val set_delimit_ssi_include : bool -> unit
(** Do we delimit included file for SSI inclusion directives or not ? *)
;;

(** {6 Non Server Side Include directives} *)

(** We define bells and whistles for directives out of Server Side Include
    directives (non-SSI directives for short). *)

val set_honor_non_ssi_directive : bool -> unit
(** Do we evaluate non-SSI directives or not ? *)
;;

val set_honor_substitution_in_text : bool -> unit
(** Do we perform substitution in text or not ? *)
;;

val set_honor_non_ssi_include : bool -> unit
(** Do we perform non-SSI file inclusion directives or not ? *)
;;

val set_honor_non_ssi_binding : bool -> unit
(** Do we perform non-SSI variable definitions or not ? *)
;;

val set_keep_non_ssi_include : bool -> unit
(** Do we perform non-SSI file inclusion directives copy or not ? *)
;;

val set_keep_non_ssi_binding : bool -> unit
(** Do we perform non-SSI variable definitions copy or not ? *)
;;

val set_ssi_mode : unit -> unit
(** Do we honor SSI directives or not ? *)
;;

val set_non_ssi_mode : unit -> unit
(** Do we honor non-SSI directives or not ? *)
;;

val set_expand_mode : unit -> unit
(** Do we expand the file argument or not ? *)
;;

val set_quote_dollar : bool -> unit
(** Do we quote dollars in text or not ? *)
;;

val set_delimit_non_ssi_include : bool -> unit
(** Do we delimit included file for non-SSI inclusion directives or not ? *)
;;

(** Internal use. *)

val add_env_file_name : Path.file_name -> unit;;
val add_bindings_file_name : Path.file_name -> unit;;
val add_definition_ident : Env.ident -> unit;;
val add_definition_value : string -> unit;;
val add_preprocessor_command : Types.command_name -> unit;;

val bind_htmlc_definitions : unit -> unit;;

val load_env_file_names : Path.file_name list -> unit;;
