(***********************************************************************)
(*                                                                     *)
(*                           CIME Caml                                 *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 1997 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(* $Id: path.mli,v 1.10 2009/08/11 22:41:44 weis Exp $ *)

(** {3 Defining a path machinery to find files in the file system} *)

exception Empty;;
(** This exception is raised when [pop] is called and the current
   directory path is empty. *)

type file_name = string
and dir_name = string
and explicit_file_name = string;;
(** The name of a file, the name of a directory, and the explicit name of a
    file. *)

type t = dir_name list;;
(** A directory path is a list of directory names. *)

val get : unit -> t;;
val push : dir_name -> unit;;
val pop : unit -> unit;;
val init : t -> unit;;
(** The path machinery:
   define a current list of directories to search files into. *)

val open_in : file_name -> in_channel;;
val open_in_bin : file_name -> in_channel;;
val open_out : file_name -> out_channel;;
(** Opening files in the current path. Equivalent to the regular open
   primitives if the file name argument is not implicit. *)

val find : file_name -> explicit_file_name;;
(** Return the explicit file name of the first file with the given name
    in the current directory path. *)

val print : Format.formatter -> t -> unit;;
(** Print the given [Path.t] into the [Formatter.formatter]. *)
